============
Introduction
============

| This is **Cookiecutter Python Package**, a *Template Project* used to *generate* fresh new open source *Python Package*'s.
| The Template is implemented as a *cookiecutter* and it is available both as source code and as a Python Package in itself.

| Goal of this project is to automate the process of creating a new Python Package, by providing the user with a "bootstrap" method,
| to quickly set up all the *support* files required to seemlessly build and publish the package on pypi.org (the official Python Pcakge Index public server).
| Additionally, it instruments a basic **Test Suite**, multiple **Commands**, as well as a **CI** pipeline, with parallel execution of the *build matrix*, running on *Github Actions*.

| This documentation aims to help people understand what are the features of the library and how they can use
| it. It presents some use cases and an overview of the library capabilities and overall design.

